<?php
/**
 * @copyright 2021 Double Bastion LLC <www.doublebastion.com>
 *
 * @author Double Bastion LLC
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
 *
 * You should have received a copy of the GNU Affero General Public
 * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

declare(strict_types=1);

return [
  'routes' => [
     // User views
     ['name' => 'page#index', 'url' => '/', 'verb' => 'GET'],
     ['name' => 'author_api#receivefaxphaxio', 'url' => '/api/recfaxphaxio', 'verb' => 'POST'],
     ['name' => 'paxfax#getbalance', 'url' => '/user/getbalance/{userId}', 'verb' => 'POST'],
     ['name' => 'paxfax#getfaxnumbers', 'url' => '/user/getfaxnumbers/{userId}', 'verb' => 'POST'],
     ['name' => 'paxfax#cleantempdir', 'url' => '/user/cleantempdir/{userId}', 'verb' => 'POST'],
     ['name' => 'paxfax#uploadfile', 'url' => '/user/uploadfile/{userId}', 'verb' => 'POST'],
     ['name' => 'paxfax#pickfile', 'url' => '/user/pickfile/{userId}', 'verb' => 'POST'],
     ['name' => 'paxfax#removeupfile', 'url' => '/user/removeupfile/{userId}', 'verb' => 'POST'],
     ['name' => 'paxfax#getpickedfile', 'url' => '/user/getpickedfile/{userId}', 'verb' => 'POST'],
     ['name' => 'paxfax#sendfax', 'url' => '/user/sendfax/{userId}', 'verb' => 'POST'],
     ['name' => 'paxfax#sendfaxpicked', 'url' => '/user/sendfaxpicked/{userId}', 'verb' => 'POST'],
     // Settings
     ['name' => 'paxfax#getsettings', 'url' => '/user/getsettings/{userId}', 'verb' => 'GET'],
     ['name' => 'paxfax#updatesettings', 'url' => '/user/updatesettings/{userId}', 'verb' => 'PUT']
  ]
];